@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2013-2016 by Jakob Schröter <js@camaya.net>
+ *  Copyright (c) 2013-2017 by Jakob Schröter <js@camaya.net>
  *  This file is part of the gloox library. http://camaya.net/gloox
  *
  *  This software is distributed under a license. The full license
@@ -39,7 +39,7 @@ namespace gloox
       return;
 
     const std::string& name = tag->name();
-    m_type = (Type)util::lookup( name, typeValues );
+    m_type = static_cast<Type>( util::lookup( name, typeValues ) );
 
     switch( m_type )
     {
