@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -28,7 +28,7 @@ namespace gloox
 
   static inline ChatStateType chatStateType( const std::string& type )
   {
-    return (ChatStateType)util::lookup2( type, stateValues );
+    return static_cast<ChatStateType>( util::lookup2( type, stateValues ) );
   }
 
   ChatState::ChatState( const Tag* tag )
