@@ -156,7 +156,7 @@ namespace gloox
       {
         logInstance().err( LogAreaClassClient, "Client is configured to require"
                                 " TLS but either the server didn't offer TLS or"
-                                " TLS support is not compiled in." );
+                                " TLS support is not compiled into gloox." );
         disconnect( ConnTlsNotAvailable );
       }
       else if( m_tls > TLSDisabled && m_encryption && !m_encryptionActive
