@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2004-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -11,6 +11,7 @@
 */
 
 
+#include "config.h"
 
 #include "gloox.h"
 
@@ -108,8 +109,8 @@ namespace gloox
                              "Unknown error condition" );
           break;
       }
-      m_handler->handleDisconnect( this, (ConnectionError)-m_socket );
-      return (ConnectionError)-m_socket;
+      m_handler->handleDisconnect( this, static_cast<ConnectionError>( -m_socket ) );
+      return static_cast<ConnectionError>( -m_socket );
     }
     else
     {
@@ -137,7 +138,11 @@ namespace gloox
       return ConnNoError;
     }
 
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
     int size = static_cast<int>( ::recv( m_socket, m_buf, m_bufsize, 0 ) );
+#else
+    int size = static_cast<int>( ::recv( m_socket, m_buf, m_bufsize, MSG_DONTWAIT ) );
+#endif
     if( size > 0 )
       m_totalBytesIn += size;
 
@@ -147,6 +152,12 @@ namespace gloox
     {
       if( size == -1 )
       {
+
+#if defined(__unix__)
+      if( errno == EAGAIN || errno == EWOULDBLOCK )
+        return ConnNoError;
+#endif
+
         // recv() failed for an unexpected reason
         std::string message = "recv() failed. "
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
