@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2004-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -81,49 +81,6 @@ namespace gloox
     return new ConnectionTCPServer( m_connectionHandler, m_logInstance, m_server, m_port );
   }
 
-  // remove for 1.1
-  int ConnectionTCPServer::getSocket( int af, int socktype, int proto, const LogSink& logInstance )
-  {
-#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-    SOCKET fd;
-#else
-    int fd;
-#endif
-    if( ( fd = ::socket( af, socktype, proto ) ) == INVALID_SOCKET )
-    {
-      std::string message = "getSocket( "
-      + util::int2string( af ) + ", "
-      + util::int2string( socktype ) + ", "
-      + util::int2string( proto )
-      + " ) failed. "
-#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-      "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
-#else
-      "errno: " + util::int2string( errno ) + ": " + strerror( errno );
-#endif
-      logInstance.dbg( LogAreaClassDns, message );
-
-#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-      if( WSACleanup() != 0 )
-      {
-        logInstance.dbg( LogAreaClassDns, "WSACleanup() failed. WSAGetLastError: "
-        + util::int2string( ::WSAGetLastError() ) );
-      }
-#endif
-
-      return -ConnConnectionRefused;
-    }
-
-#ifdef HAVE_SETSOCKOPT
-    int timeout = 5000;
-    int reuseaddr = 1;
-    setsockopt( fd, SOL_SOCKET, SO_SNDTIMEO, (char*)&timeout, sizeof( timeout ) );
-    setsockopt( fd, SOL_SOCKET, SO_REUSEADDR, (char*)&reuseaddr, sizeof( reuseaddr ) );
-#endif
-
-    return (int)fd;
-  }
-
   ConnectionError ConnectionTCPServer::connect()
   {
     util::MutexGuard mg( &m_sendMutex );
@@ -146,13 +103,11 @@ namespace gloox
 #else
     socklen_t bufbytes = sizeof( int );
 #endif
-    if( ( getsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, (char*)&buf, &bufbytes ) != -1 ) &&
-        ( m_bufsize > buf ) )
-      setsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, (char*)&m_bufsize, sizeof( m_bufsize ) );
+    if( ( getsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, reinterpret_cast<char*>( &buf ), &bufbytes ) != -1 ) && ( m_bufsize > buf ) )
+      setsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, reinterpret_cast<const char*>( &m_bufsize ), sizeof( m_bufsize ) );
 
-    if( ( getsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, (char*)&buf, &bufbytes ) != -1 ) &&
-        ( m_bufsize > buf ) )
-      setsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, (char*)&m_bufsize, sizeof( m_bufsize ) );
+    if( ( getsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, reinterpret_cast<char*>( &buf ), &bufbytes ) != -1 ) && ( m_bufsize > buf ) )
+      setsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, reinterpret_cast<const char*>( &m_bufsize ), sizeof( m_bufsize ) );
 #endif
 
     int status = 0;
@@ -177,11 +132,10 @@ namespace gloox
 #endif
       m_logInstance.dbg( LogAreaClassConnectionTCPServer, message );
 
+      DNS::closeSocket( m_socket, m_logInstance );
       return ConnIoError;
     }
 
-    m_socket = ::socket( res->ai_family, res->ai_socktype, res->ai_protocol );
-
     if( bind( m_socket, res->ai_addr, res->ai_addrlen ) < 0 )
     {
       err = errno;
@@ -237,16 +191,16 @@ namespace gloox
     struct sockaddr_storage they;
     int addr_size = sizeof( struct sockaddr_storage );
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
-    int newfd = static_cast<int>( accept( static_cast<SOCKET>( m_socket ), (struct sockaddr*)&they, &addr_size ) );
+    int newfd = static_cast<int>( accept( static_cast<SOCKET>( m_socket ), reinterpret_cast<struct sockaddr*>( &they ), &addr_size ) );
 #else
-    int newfd = accept( m_socket, (struct sockaddr*)&they, (socklen_t*)&addr_size );
+    int newfd = accept( m_socket, reinterpret_cast<struct sockaddr*>( &they ), reinterpret_cast<socklen_t*>( &addr_size ) );
 #endif
 
     m_recvMutex.unlock();
 
     char buffer[INET6_ADDRSTRLEN];
     char portstr[NI_MAXSERV];
-    int err = getnameinfo( (struct sockaddr*)&they, addr_size, buffer, sizeof( buffer ),
+    int err = getnameinfo( reinterpret_cast<struct sockaddr*>( &they ), addr_size, buffer, sizeof( buffer ),
                            portstr, sizeof( portstr ), NI_NUMERICHOST | NI_NUMERICSERV );
     if( err )
       return ConnIoError;
