@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -69,7 +69,7 @@ namespace gloox
       m_type = TypeForm;
     else
     {
-      m_type = (FormType)util::lookup( type, dfTypeValues );
+      m_type = static_cast<FormType>( util::lookup( type, dfTypeValues ) );
       if( m_type == TypeInvalid )
         return false;
     }
