@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -48,7 +48,7 @@ namespace gloox
         m_type = TypeNone;
     }
     else
-      m_type = (FieldType)util::lookup( type, fieldTypeValues );
+      m_type = static_cast<FieldType>( util::lookup( type, fieldTypeValues ) );
 
     if( tag->hasAttribute( "var" ) )
       m_name = tag->findAttribute( "var" );
