@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -32,7 +32,7 @@ namespace gloox
     if( !tag || tag->name() != "iq" )
       return;
 
-    m_subtype = (IQ::IqType)util::lookup( tag->findAttribute( TYPE ), iqTypeStringValues );
+    m_subtype = static_cast<IQ::IqType>( util::lookup( tag->findAttribute( TYPE ), iqTypeStringValues ) );
   }
 
   IQ::IQ( IqType type, const JID& to, const std::string& id )
