@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -101,7 +101,7 @@ namespace gloox
       return false;
 
     IQ re( IQ::Result, iq.from(), iq.id() );
-    re.addExtension( new Query( EmptyString, (long)( time( 0 ) - m_active ) ) );
+    re.addExtension( new Query( EmptyString, static_cast<long>( time( 0 ) - m_active ) ) );
     m_parent->send( re );
 
     return true;
