@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -36,7 +36,7 @@ namespace gloox
     if( typestring.empty() )
       m_subtype = Normal;
     else
-      m_subtype = (MessageType)util::lookup2( typestring, msgTypeStringValues );
+      m_subtype = static_cast<MessageType>( util::lookup2( typestring, msgTypeStringValues ) );
 
     const TagList& c = tag->children();
     TagList::const_iterator it = c.begin();
