@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -53,7 +53,7 @@ namespace gloox
     }
 
     if( msg.body().empty() )
-      m_messageEventHandler->handleMessageEvent( msg.from(), (MessageEventType)me->event() );
+      m_messageEventHandler->handleMessageEvent( msg.from(), static_cast<MessageEventType>( me->event() ) );
     else
     {
       m_lastID = msg.id();
