@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2006-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -52,12 +52,12 @@ namespace gloox
 
   static inline MUCRoomAffiliation affiliationType( const std::string& type )
   {
-    return (MUCRoomAffiliation)util::lookup( type, affiliationValues );
+    return static_cast<MUCRoomAffiliation>( util::lookup( type, affiliationValues ) );
   }
 
   static inline MUCRoomRole roleType( const std::string& type )
   {
-    return (MUCRoomRole)util::lookup( type, roleValues );
+    return static_cast<MUCRoomRole>( util::lookup( type, roleValues ) );
   }
 
   MUCRoom::MUCAdmin::MUCAdmin( MUCRoomRole role, const std::string& nick,
@@ -1135,7 +1135,7 @@ namespace gloox
       case StoreMemberList:
       case StoreModeratorList:
       case StoreAdminList:
-        m_roomConfigHandler->handleMUCConfigResult( this, true, (MUCOperation)context );
+        m_roomConfigHandler->handleMUCConfigResult( this, true, static_cast<MUCOperation>( context ) );
         break;
       case RequestRoomConfig:
       {
@@ -1158,7 +1158,7 @@ namespace gloox
         if( !ma )
           break;
 
-        m_roomConfigHandler->handleMUCConfigList( this, ma->list(), (MUCOperation)context );
+        m_roomConfigHandler->handleMUCConfigList( this, ma->list(), static_cast<MUCOperation>( context ) );
         break;
       }
       default:
@@ -1196,7 +1196,7 @@ namespace gloox
       case StoreOwnerList:
       case RequestAdminList:
       case StoreAdminList:
-        m_roomConfigHandler->handleMUCConfigResult( this, false, (MUCOperation)context );
+        m_roomConfigHandler->handleMUCConfigResult( this, false, static_cast<MUCOperation>( context ) );
         break;
     }
   }
