@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@ namespace gloox
 
   static inline Receipt::ReceiptType receiptType( const std::string& type )
   {
-    return (Receipt::ReceiptType)util::lookup( type, receiptValues );
+    return static_cast<Receipt::ReceiptType>( util::lookup( type, receiptValues ) );
   }
 
   Receipt::Receipt( const Tag* tag )
