@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -168,7 +168,7 @@ namespace gloox
       {
         char c[2];
         c[0] = 0x05;
-        c[1] = (char)(unsigned char)0xFF;
+        c[1] = static_cast<char>( 0xFF );
         (*it).second.state = StateDisconnected;
 
         if( data.length() >= 3 && data[0] == 0x05 )
