@@ -22,9 +22,12 @@
 #include <cstdlib>
 
 #include <openssl/err.h>
-#include <openssl/comp.h>
 #include <openssl/x509v3.h>
 
+#ifndef OPENSSL_NO_COMP
+  #include <openssl/comp.h>
+#endif
+
 #include <string.h>
 
 namespace gloox
@@ -56,7 +59,9 @@ namespace gloox
       SSL_library_init();
 #endif // OPENSSL_VERSION_NUMBER < 0x10100000
 
+#ifndef OPENSSL_NO_COMP
     SSL_COMP_add_compression_method( 193, COMP_zlib() );
+#endif // OPENSSL_NO_COMP
 
     OpenSSL_add_all_algorithms();
 
