@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2009-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -92,7 +92,7 @@ namespace gloox
       };
 
       void doTLSOperation( TLSOperation op );
-      int openSSLTime2UnixTime( const char* time_string );
+      int ASN1Time2UnixTime( ASN1_TIME* time );
 
       std::string m_recvBuffer;
       std::string m_sendBuffer;
