@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2005-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,10 +30,12 @@ namespace gloox
 
   bool OpenSSLClient::setType()
   {
-    m_ctx = SSL_CTX_new( TLSv1_client_method() );
+    m_ctx = SSL_CTX_new( SSLv23_client_method() );
     if( !m_ctx )
       return false;
 
+    SSL_CTX_set_options( m_ctx, SSL_OP_NO_SSLv3 );
+
     return true;
   }
 
@@ -45,8 +47,8 @@ namespace gloox
   const std::string OpenSSLClient::channelBinding() const
   {
     unsigned char* buf[128];
-    int res = SSL_get_finished( m_ssl, buf, 128 );
-    return std::string( (char*)buf, res );
+    long res = SSL_get_finished( m_ssl, buf, 128 );
+    return std::string( reinterpret_cast<char*>( buf ), res );
   }
 
   int OpenSSLClient::handshakeFunction()
